# PERF02-BP02: Understand available compute configuration options

## Description

Know instance types, sizing, và configuration options.

## Implementation Guidance

- Study available instance families
- Understand CPU vs memory optimized
- Know GPU/specialized instances
- Learn about burstable vs dedicated
- Document instance selection criteria

## Risk Level

Low - Understanding options enables better choices.

## Related Best Practices

- [PERF02-BP01](PERF02-BP01-Select-Compute-Options.md)
- [PERF02-BP04](PERF02-BP04-Right-Sizing.md)
